diff --git a/Alignment/CommonAlignment/python/tools/trackselectionRefitting.py b/Alignment/CommonAlignment/python/tools/trackselectionRefitting.py
index f936131c428b5..0a15276f22dd1 100644
--- a/Alignment/CommonAlignment/python/tools/trackselectionRefitting.py
+++ b/Alignment/CommonAlignment/python/tools/trackselectionRefitting.py
@@ -363,10 +363,6 @@ def getSequence(process, collection,
## put the sequence together ##
###############################
- if "Fast" in TTRHBuilder:
- print("PixelCPEFast has been chosen, here we must include CUDAService first")
- process.load('HeterogeneousCore.CUDAServices.CUDAService_cfi')
-
modules = []
src = collection
prevsrc = None
diff --git a/Alignment/CommonAlignment/test/BuildFile.xml b/Alignment/CommonAlignment/test/BuildFile.xml
index 95ff2383508dd..2afa62a939d3f 100644
--- a/Alignment/CommonAlignment/test/BuildFile.xml
+++ b/Alignment/CommonAlignment/test/BuildFile.xml
@@ -1,4 +1,4 @@
-
+
diff --git a/Alignment/MillePedeAlignmentAlgorithm/test/BuildFile.xml b/Alignment/MillePedeAlignmentAlgorithm/test/BuildFile.xml
index 76fd64b3c4fbd..76277ee0b731d 100644
--- a/Alignment/MillePedeAlignmentAlgorithm/test/BuildFile.xml
+++ b/Alignment/MillePedeAlignmentAlgorithm/test/BuildFile.xml
@@ -5,18 +5,13 @@
-
+
-
-
-
-
-
-
-
+
+
-
+
diff --git a/Alignment/MillePedeAlignmentAlgorithm/test/TestDriver.cpp b/Alignment/MillePedeAlignmentAlgorithm/test/TestDriver.cpp
deleted file mode 100644
index 2f0e0c40064da..0000000000000
--- a/Alignment/MillePedeAlignmentAlgorithm/test/TestDriver.cpp
+++ /dev/null
@@ -1,2 +0,0 @@
-#include "FWCore/Utilities/interface/TestHelper.h"
-RUNTEST()
diff --git a/Alignment/MillePedeAlignmentAlgorithm/test/test_payload_sanity.sh b/Alignment/MillePedeAlignmentAlgorithm/test/test_payload_sanity.sh
index 6d5d888e0f06f..55191e29e75cc 100755
--- a/Alignment/MillePedeAlignmentAlgorithm/test/test_payload_sanity.sh
+++ b/Alignment/MillePedeAlignmentAlgorithm/test/test_payload_sanity.sh
@@ -1,6 +1,6 @@
#!/bin/bash
function die { echo $1: status $2; exit $2; }
-INPUTFILE=${LOCAL_TEST_DIR}/alignments_MP.db
-(cmsRun ${LOCAL_TEST_DIR}/AlignmentRcdChecker_cfg.py inputSqliteFile=${INPUTFILE}) || die 'failed running AlignmentRcdChecker'
+INPUTFILE=${SCRAM_TEST_PATH}/alignments_MP.db
+(cmsRun ${SCRAM_TEST_PATH}/AlignmentRcdChecker_cfg.py inputSqliteFile=${INPUTFILE}) || die 'failed running AlignmentRcdChecker'
rm $INPUTFILE
diff --git a/Alignment/MillePedeAlignmentAlgorithm/test/test_pede.sh b/Alignment/MillePedeAlignmentAlgorithm/test/test_pede.sh
index f1345b9e690a1..137c4df7cfde6 100755
--- a/Alignment/MillePedeAlignmentAlgorithm/test/test_pede.sh
+++ b/Alignment/MillePedeAlignmentAlgorithm/test/test_pede.sh
@@ -1,10 +1,7 @@
#!/bin/bash
function die { echo $1: status $2; exit $2; }
-if [ "${SCRAM_TEST_NAME}" != "" ] ; then
- mkdir ${SCRAM_TEST_NAME}
- cd ${SCRAM_TEST_NAME}
-fi
+LOCAL_TEST_DIR=${SCRAM_TEST_PATH}
clean_up(){
echo "cleaning the local test area"
diff --git a/Alignment/OfflineValidation/README.md b/Alignment/OfflineValidation/README.md
index b00feb3e8b64c..02dd633ff9ca4 100644
--- a/Alignment/OfflineValidation/README.md
+++ b/Alignment/OfflineValidation/README.md
@@ -1,4 +1,4 @@
-# Validation
+# Aligment/OfflineValidation
We use the Boost library (Program Options, Filesystem & Property Trees) to deal with the treatment of the config file.
Basic idea:
@@ -89,10 +89,10 @@ The python file returns a list of jobs to the `validateAligments.py` which final
- unification of local configuration style based on DMR/PV example
- plotting style options to be implemented
- change marker size for trends
- - accept ROOT pre-defined encoding in config (kRed, kDotted, etc.)
+ - accept ROOT pre-defined encoding in config (`kRed`, `kDotted`, etc.)
- validations to implement:
- PV (only average is missing)
- - Zµµ (single + merge)
+ - Zµµ (trend)
- MTS (single + merge)
- overlap (single + merge + trend)
- ...
@@ -106,13 +106,13 @@ The python file returns a list of jobs to the `validateAligments.py` which final
(list from October 2022)
## DMR validation
-For details read `README_DMR.md`
+For details read [`README_DMR.md`](https://github.com/cms-sw/cmssw/blob/master/Alignment/OfflineValidation/README_DMR.md)
## PV validation
-For details read `README_PV.md`
+For details read [`README_PV.md`](https://github.com/cms-sw/cmssw/blob/master/Alignment/OfflineValidation/README_PV.md)
## JetHT validation
-For details read `README_JetHT.md`
+For details read [`README_JetHT.md`](https://github.com/cms-sw/cmssw/blob/master/Alignment/OfflineValidation/README_JetHT.md)
## General info about IOV/run arguments
-For details read `README_IOV.md`
+For details read [`README_IOV.md`](https://github.com/cms-sw/cmssw/blob/master/Alignment/OfflineValidation/README_IOV.md)
diff --git a/Alignment/OfflineValidation/README_DMR.md b/Alignment/OfflineValidation/README_DMR.md
index bf27da51dac51..1134a5f74bf3e 100644
--- a/Alignment/OfflineValidation/README_DMR.md
+++ b/Alignment/OfflineValidation/README_DMR.md
@@ -1,6 +1,6 @@
-## DMR validation
-
-#General info
+# Track-Hit Residuals Validation (DMR, DRnR, etc.)
+
+## General info
```
validations:
DMR:
@@ -20,7 +20,7 @@ Trends/Averaged job will start if all corresponding merge jobs are done.
Trends and averaged jobs will run in parallel.
Averaged job consists of 3 types of sub-jobs (submission is automatized internally).
-#Single DMR jobs:
+## Single DMR jobs
Single jobs can be specified per run (IoV as well). In case of MC, IoV is specified to arbitrary 1.
Variable | Default value | Explanation/Options
@@ -38,7 +38,7 @@ usePixelQualityFlag | True | Use pixel quality flag?
cosmicsZeroTesla | False | Is this validation for cosmics with zero magnetic field?
vertexcollection | "offlinePrimaryVertices" | Specify vertex collection to be used.
-#Merge DMR job
+## Merge DMR job
Its name do not need to match single job name but option `singles` must list all single jobs to be merged.
Needs to be specified in order to run averaged/trends jobs.
DMR merged plot style can be adjusted from global plotting style (see `Alignment/OfflineValidation/test/example_DMR_full.yaml`)
@@ -56,7 +56,7 @@ minimum | 15 | Minimum number of hits requested.
bigtext | false | Legend text size should be enlarged.
moduleid | None | Plot residuals for selected list of module IDs. (debugging)
-#Trends DMR job
+## Trends DMR job
Its name do not need to match merge neither single job name but option `merges` must list all merge jobs to be put in trend plot.
Trend plot style is defined globally for all trend plots (see `Alignment/OfflineValidation/test/example_DMR_full.yaml`)
@@ -69,7 +69,7 @@ lastRun | 325175 | Specify the last run to be considered.
labels | None | List of string tags to be added in output rootfile.
year | Run2 | Enforce year tag to be included in lumiInputFile option specified in trend style (This is extra measure)
-#Averaged DMR job
+## Averaged DMR job
Its name do not need to match merge neither single job name but option `merges` must list all merge jobs to be put in averaged distribution.
Each merge job to be passed to averager must consist of data OR MC single jobs exclusively (no mix of Data and MC).
Some style options are accessible from global style config (see `Alignment/OfflineValidation/test/example_DMR_full.yaml`).
diff --git a/Alignment/OfflineValidation/README_IOV.md b/Alignment/OfflineValidation/README_IOV.md
index 4ffae09127c93..8587d3e517abc 100644
--- a/Alignment/OfflineValidation/README_IOV.md
+++ b/Alignment/OfflineValidation/README_IOV.md
@@ -1,4 +1,4 @@
-Following document summarises usage of IOV/run-driven validations.
+The following document summarises usage of IOV/run-driven validations.
## DMR and PV
diff --git a/Alignment/OfflineValidation/README_JetHT.md b/Alignment/OfflineValidation/README_JetHT.md
index be3dcb0393052..ced3361f49da2 100644
--- a/Alignment/OfflineValidation/README_JetHT.md
+++ b/Alignment/OfflineValidation/README_JetHT.md
@@ -1,6 +1,6 @@
-## JetHT validation
+# JetHT validation
-### Validation analysis - JetHT_cfg.py
+## Validation analysis - JetHT_cfg.py
The vast majority of the time in the JetHT validation goes to running the actual validation analysis. This is done with cmsRun using the JetHT_cfg.py configuration file. To configure the analysis in the all-in-one framework, the following parameters can be set in the json/yaml configuration file:
@@ -29,7 +29,7 @@ profilePtBorders | [3,5,10,20,50,100] | List for pT borders used in wide pT bin
TrackerAlignmentRcdFile | "nothing" | Local database file from which the TrackerAlignmentRcd is read. Notice that usual method to set this is reading from the database for each alignment.
TrackerAlignmentErrorFile | "nothing" | Local database file from which the TrackerAlignmentExtendedErrorRcd is read. Notice that usual method to set this is reading from the database for each alignment.
-### File merging - addHistograms.sh
+## File merging - addHistograms.sh
The addHistograms.sh script is used to merge the root files for jetHT validation. Merging is fast and can easily be done locally in seconds, but the tool is fully integrated to the all-in-one configuration for automated processing.
@@ -61,8 +61,7 @@ Variable | Default value | Explanation
singles | None | An array of single job names that must be finished before plotting can be run.
alignments | None | An array of alignment names for which the files are merged within those alignments. Different alignments are kept separate.
-
-### Plotting - jetHtPlotter
+## Plotting - jetHtPlotter
The tool is originally designed to be used standalone, since the plotting the histograms locally does not take more that tens of second at maximum. But the plotter works also together with the all-in-one configuration. The only difference for user is the structure of the configuration file, that changes a bit between standalone and all-in-one usage.
diff --git a/Alignment/OfflineValidation/README_PV.md b/Alignment/OfflineValidation/README_PV.md
index 5106a57db7226..1ffcc07247b03 100644
--- a/Alignment/OfflineValidation/README_PV.md
+++ b/Alignment/OfflineValidation/README_PV.md
@@ -1,6 +1,6 @@
-## PV validation
+# Primary Vertex (PV) Validation
-#General info
+## General info
```
validations:
PV:
@@ -18,7 +18,7 @@ Merge job and trend jobs will only start if all corresponding single jobs are do
Trend and merge jobs can run in parallel.
Averaged jobs are not yet implemented.
-#Single PV jobs:
+## Single PV jobs
Single jobs can be specified per run (IoV as well). In case of MC, IoV is specified to arbitrary 1.
Variable | Default value | Explanation/Options
@@ -47,7 +47,7 @@ doFPix | True | Do not run validation for FPix if needed
forceBeamSpot | False | Force beam spot
numberOfBins | 48 | Define histogram granularity
-#Merge PV job
+## Merge PV job
Its name do not need to match single job name but option `singles` must list all single jobs to be merged.
PV merged plot style can be adjusted from global plotting style (see `Alignment/OfflineValidation/test/example_PV_full.yaml`)
@@ -75,7 +75,7 @@ w_dxyEtaNormMax | 1.8 | If not take this...
w_dzEtaNormMax | 1.8 | If not take this...
customrighttitle | "" | Top right title. Reserved word "IOV" will be replaced for given IOV/run in the list.
-#Trends PV job
+## Trends PV job
Its name do not need to match single job name but option `singles` must list all single jobs to be put in trend plot.
Trend plot style is defined globally for all trend plots (see `Alignment/OfflineValidation/test/example_PV_full.yaml`)
@@ -88,4 +88,3 @@ firstRun | 272930 | Specify starting run to be plotted.
lastRun | 325175 | Specify the last run to be considered.
nWorkers | 20 | Number of threads.
doUnitTest | false | Disable certain settings for unit test.
-
diff --git a/Alignment/OfflineValidation/bin/JDrawer.h b/Alignment/OfflineValidation/bin/JDrawer.h
index 5bcc06cea90ea..9174b840238bd 100644
--- a/Alignment/OfflineValidation/bin/JDrawer.h
+++ b/Alignment/OfflineValidation/bin/JDrawer.h
@@ -216,22 +216,7 @@ class JDrawer {
/*
* Destructor for JDrawer
*/
- ~JDrawer() {
- if (fCanvas)
- delete fCanvas;
- if (fSinglePad)
- delete fSinglePad;
- if (fUpperSplitPad)
- delete fUpperSplitPad;
- if (fLowerSplitPad)
- delete fLowerSplitPad;
- if (fLeftRowPad)
- delete fLeftRowPad;
- if (fMiddleRowPad)
- delete fMiddleRowPad;
- if (fRightRowPad)
- delete fRightRowPad;
- }
+ ~JDrawer() = default;
/*
* Draw a histogram to a canvas
diff --git a/Alignment/OfflineValidation/bin/Zmumumerge.cc b/Alignment/OfflineValidation/bin/Zmumumerge.cc
index 1995da4120a2e..1708273da083a 100644
--- a/Alignment/OfflineValidation/bin/Zmumumerge.cc
+++ b/Alignment/OfflineValidation/bin/Zmumumerge.cc
@@ -221,13 +221,13 @@ void Draw_TH1D_forMultiRootFiles(const vector& file_names,
for (auto const& filename : file_names | boost::adaptors::indexed(0)) {
file_input[filename.index()] = TFile::Open(filename.value());
th1d_input[filename.index()] = (TH1D*)file_input[filename.index()]->Get(th1d_name);
+ th1d_input[filename.index()]->SetTitle("");
}
TCanvas* c = new TCanvas();
TLegend* lg = new TLegend(0.2, 0.7, 0.5, 0.95);
c->cd();
gStyle->SetOptStat(0);
- th1d_input[0]->SetTitle("");
for (auto const& labelname : label_names | boost::adaptors::indexed(0)) {
th1d_input[labelname.index()]->SetMarkerColor(colors[labelname.index()]);
diff --git a/Alignment/OfflineValidation/bin/jetHtPlotter.cc b/Alignment/OfflineValidation/bin/jetHtPlotter.cc
index 116a7e72b0913..83fb9ffd1891b 100644
--- a/Alignment/OfflineValidation/bin/jetHtPlotter.cc
+++ b/Alignment/OfflineValidation/bin/jetHtPlotter.cc
@@ -1,3 +1,7 @@
+// framework includes
+#include "FWCore/ParameterSet/interface/FileInPath.h"
+#include "FWCore/MessageLogger/interface/MessageLogger.h"
+
// C++ includes
#include // Input/output stream. Needed for cout.
#include
@@ -256,7 +260,12 @@ std::tuple, std::vector, std::vector, std::vec
double thisLumi;
// Load the iovList
- std::ifstream iovList(inputFile);
+ std::ifstream iovList(edm::FileInPath(inputFile).fullPath().c_str());
+ if (!iovList.good()) {
+ edm::LogError("jetHTPlotter") << __PRETTY_FUNCTION__ << "\n Input file: " << inputFile
+ << " is corrupt or not existing";
+ return std::make_tuple(iovVector, lumiPerIov, iovNames, iovLegend);
+ }
// Go through the file line by line. Each line has an IOV boundary and luminosity for this IOV.
while (std::getline(iovList, lineInFile)) {
@@ -643,6 +652,11 @@ void jetHtPlotter(std::string configurationFileName) {
std::vector iovLegend;
std::tie(iovVector, lumiPerIov, iovNames, iovLegend) = runAndLumiLists(iovAndLumiFile, iovListMode);
+ // protection against empty input
+ if (iovVector.empty()) {
+ edm::LogError("jetHTPlotter") << __PRETTY_FUNCTION__ << "\n The list of input IOVs is empty. Exiting!";
+ return;
+ }
// For the IOV legend, remove the two last entries and replace them with user defined names
iovLegend.pop_back();
diff --git a/Alignment/OfflineValidation/plugins/GeneralPurposeTrackAnalyzer.cc b/Alignment/OfflineValidation/plugins/GeneralPurposeTrackAnalyzer.cc
index 195a354c2c45e..e73449fefa8fe 100644
--- a/Alignment/OfflineValidation/plugins/GeneralPurposeTrackAnalyzer.cc
+++ b/Alignment/OfflineValidation/plugins/GeneralPurposeTrackAnalyzer.cc
@@ -995,8 +995,8 @@ class GeneralPurposeTrackAnalyzer : public edm::one::EDAnalyzer theRuns_;
for (const auto &it : conditionsMap_) {
@@ -1037,11 +1046,12 @@ class GeneralPurposeTrackAnalyzer : public edm::one::EDAnalyzer("modeByRun",
"Strip APV mode by run number;;APV mode (-1=deco,+1=peak)",
@@ -1055,6 +1065,8 @@ class GeneralPurposeTrackAnalyzer : public edm::one::EDAnalyzersecond.first != 0) {
edm::LogPrint("GeneralPurposeTrackAnalyzer")
diff --git a/Alignment/OfflineValidation/plugins/TrackerGeometryCompare.cc b/Alignment/OfflineValidation/plugins/TrackerGeometryCompare.cc
index 07fc39a1631d3..c4e560292c29b 100644
--- a/Alignment/OfflineValidation/plugins/TrackerGeometryCompare.cc
+++ b/Alignment/OfflineValidation/plugins/TrackerGeometryCompare.cc
@@ -70,7 +70,7 @@ TrackerGeometryCompare::TrackerGeometryCompare(const edm::ParameterSet& cfg)
fromDD4hep_(cfg.getUntrackedParameter("fromDD4hep")),
writeToDB_(cfg.getUntrackedParameter("writeToDB")),
commonTrackerLevel_(align::invalid),
- moduleListFile_(nullptr),
+ moduleListFile_(),
moduleList_(0),
inputRootFile1_(nullptr),
inputRootFile2_(nullptr),
@@ -337,8 +337,9 @@ void TrackerGeometryCompare::createROOTGeometry(const edm::EventSetup& iSetup) {
AlignTransform transform1(translation1, eulerangles1, detid1);
alignments1->m_align.push_back(transform1);
- //dummy errors
- CLHEP::HepSymMatrix clhepSymMatrix(3, 0);
+ // dummy errors
+ // APE matrix was 3x3, now it's 6x6 (because of muons), see PR #6483
+ CLHEP::HepSymMatrix clhepSymMatrix(6, 0);
AlignTransformErrorExtended transformError(clhepSymMatrix, detid1);
alignmentErrors1->m_alignError.push_back(transformError);
}
@@ -371,8 +372,9 @@ void TrackerGeometryCompare::createROOTGeometry(const edm::EventSetup& iSetup) {
AlignTransform transform2(translation2, eulerangles2, detid2);
alignments2->m_align.push_back(transform2);
- //dummy errors
- CLHEP::HepSymMatrix clhepSymMatrix(3, 0);
+ // dummy errors
+ // APE matrix was 3x3, now it's 6x6 (because of muons), see PR #6483
+ CLHEP::HepSymMatrix clhepSymMatrix(6, 0);
AlignTransformErrorExtended transformError(clhepSymMatrix, detid2);
alignmentErrors2->m_alignError.push_back(transformError);
}
diff --git a/Alignment/OfflineValidation/python/TkAlAllInOneTool/JetHT_cfg.py b/Alignment/OfflineValidation/python/TkAlAllInOneTool/JetHT_cfg.py
index 523c29afdca25..6984e04e5a8b6 100644
--- a/Alignment/OfflineValidation/python/TkAlAllInOneTool/JetHT_cfg.py
+++ b/Alignment/OfflineValidation/python/TkAlAllInOneTool/JetHT_cfg.py
@@ -5,6 +5,7 @@
# Define the process
import FWCore.ParameterSet.Config as cms
+from Alignment.OfflineValidation.TkAlAllInOneTool.defaultInputFiles_cff import filesDefaultData_JetHTRun2018D
process = cms.Process("JetHTAnalyzer")
# Choose whether to run with Monte Carlo or data settings based on command line argument
@@ -169,9 +170,7 @@
else:
print(">>>>>>>>>> JetHT_cfg.py: msg%-i: Default file read from 2018D JetHT dataset.")
process.source = cms.Source("PoolSource",
- fileNames = cms.untracked.vstring('root://xrootd-cms.infn.it//store/data/Run2018D/JetHT/ALCARECO/TkAlMinBias-12Nov2019_UL2018-v4/00000/009085FF-603B-044D-8879-0599B156831D.root') # A file from 2018 JetHT file in DESY
-
- )
+ fileNames = filesDefaultData_JetHTRun2018D)
####################################################################
# Global tag
@@ -265,7 +264,7 @@
###################################################################
# The analysis module
###################################################################
-from Alignment.OfflineValidation.jetHTAnalyzer_cfi.py import jetHTAnalyzer as _jetHTAnalyzer
+from Alignment.OfflineValidation.jetHTAnalyzer_cfi import jetHTAnalyzer as _jetHTAnalyzer
process.jetHTAnalyzer = _jetHTAnalyzer.clone(
vtxCollection = "offlinePrimaryVerticesFromRefittedTrks",
trackCollection = "TrackRefitter",
diff --git a/Alignment/OfflineValidation/scripts/submitPVValidationJobs.py b/Alignment/OfflineValidation/scripts/submitPVValidationJobs.py
index 62538355662fd..9a708ac97ad5f 100755
--- a/Alignment/OfflineValidation/scripts/submitPVValidationJobs.py
+++ b/Alignment/OfflineValidation/scripts/submitPVValidationJobs.py
@@ -443,7 +443,7 @@ def createTheCfgFile(self,lfn):
self.outputCfgName=self.output_full_name+"_cfg.py"
fout=open(os.path.join(self.cfg_dir,self.outputCfgName),'w')
- template_cfg_file = os.path.join(self.the_dir,"PVValidation_T_cfg.py")
+ template_cfg_file = os.path.join(self.CMSSW_dir,"src/Alignment/OfflineValidation/test","PVValidation_T_cfg.py")
file = open(template_cfg_file,'r')
config_txt = '\n\n' + CopyRights + '\n\n'
@@ -622,8 +622,7 @@ def main():
# CMSSW section
input_CMSSW_BASE = os.environ.get('CMSSW_BASE')
- AnalysisStep_dir = os.path.join(input_CMSSW_BASE,"src/Alignment/OfflineValidation/test")
- lib_path = os.path.abspath(AnalysisStep_dir)
+ lib_path = os.path.abspath(os.path.join(input_CMSSW_BASE,"src/Alignment/OfflineValidation/test"))
sys.path.append(lib_path)
## N.B.: this is dediced here once and for all
@@ -923,7 +922,7 @@ def main():
## print "==========>",conditions
# for hadd script
- scripts_dir = os.path.join(AnalysisStep_dir,"scripts")
+ scripts_dir = "scripts"
if not os.path.exists(scripts_dir):
os.makedirs(scripts_dir)
hadd_script_file = os.path.join(scripts_dir,jobName[iConf]+"_"+opts.taskname+".sh")
@@ -1055,7 +1054,7 @@ def main():
vertextype[iConf], tracktype[iConf],
refittertype[iConf], ttrhtype[iConf],
applyruncontrol[iConf],
- ptcut[iConf],input_CMSSW_BASE,AnalysisStep_dir)
+ ptcut[iConf],input_CMSSW_BASE,'.')
aJob.setEOSout(eosdir)
aJob.createTheCfgFile(theSrcFiles)
diff --git a/Alignment/OfflineValidation/test/BuildFile.xml b/Alignment/OfflineValidation/test/BuildFile.xml
index 91b7ed8a424b2..b557a9c8db03c 100644
--- a/Alignment/OfflineValidation/test/BuildFile.xml
+++ b/Alignment/OfflineValidation/test/BuildFile.xml
@@ -1,36 +1,25 @@
-
-
-
-
-
+
+
-
-
-
-
+
+
-
-
-
-
+
+
-
-
-
-
+
+
-
-
-
+
+
+
+
-
-
-
-
+
@@ -38,22 +27,10 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
@@ -61,8 +38,5 @@
-
-
-
-
+
diff --git a/Alignment/OfflineValidation/test/testAlignmentOfflineValidation.cpp b/Alignment/OfflineValidation/test/testAlignmentOfflineValidation.cpp
deleted file mode 100644
index 2f0e0c40064da..0000000000000
--- a/Alignment/OfflineValidation/test/testAlignmentOfflineValidation.cpp
+++ /dev/null
@@ -1,2 +0,0 @@
-#include "FWCore/Utilities/interface/TestHelper.h"
-RUNTEST()
diff --git a/Alignment/OfflineValidation/test/testPrimaryVertexRelatedValidations_cfg.py b/Alignment/OfflineValidation/test/testPrimaryVertexRelatedValidations_cfg.py
index 7dd29a81fdbda..ff4ba59b8cfef 100644
--- a/Alignment/OfflineValidation/test/testPrimaryVertexRelatedValidations_cfg.py
+++ b/Alignment/OfflineValidation/test/testPrimaryVertexRelatedValidations_cfg.py
@@ -30,10 +30,7 @@ class RefitType(Enum):
_allFromGT = True
_applyBows = True
_applyExtraConditions = True
-if(options.isPhase2):
- _theRefitter = RefitType.STANDARD # FIXME: once the sequence is cleared out
-else:
- _theRefitter = RefitType.COMMON
+_theRefitter = RefitType.COMMON # RefitType.STANDARD (other option not involving filtering)
_theTrackCollection = 'generalTracks' # FIXME: 'ALCARECOTkAlMinBias' once a sample is available
###################################################################
@@ -121,7 +118,7 @@ class RefitType(Enum):
####################################################################
process.load("Configuration.StandardSequences.FrontierConditions_GlobalTag_cff")
from Configuration.AlCa.GlobalTag import GlobalTag
-process.GlobalTag = GlobalTag(process.GlobalTag, ('auto:phase2_realistic' if options.isPhase2 else 'auto:phase1_2022_realistic'), '')
+process.GlobalTag = GlobalTag(process.GlobalTag, ('auto:phase2_realistic_T21' if options.isPhase2 else 'auto:phase1_2022_realistic'), '')
if _allFromGT:
print("############ testPVValidation_cfg.py: msg%-i: All is taken from GT")
diff --git a/Alignment/OfflineValidation/test/testTrackAnalyzers.cc b/Alignment/OfflineValidation/test/testTrackAnalyzers.cc
index 78835dae81b42..1874fcbacbd2a 100644
--- a/Alignment/OfflineValidation/test/testTrackAnalyzers.cc
+++ b/Alignment/OfflineValidation/test/testTrackAnalyzers.cc
@@ -27,10 +27,10 @@ process.add_(cms.Service('TFileService',fileName=cms.string('tesTrackAnalyzer1.r
// REQUIRE_NOTHROW(tester.test());
// }
- // SECTION("beginJob and endJob only") {
- // edm::test::TestProcessor tester(config);
- // REQUIRE_NOTHROW(tester.testBeginAndEndJobOnly());
- // }
+ SECTION("beginJob and endJob only") {
+ edm::test::TestProcessor tester(config);
+ REQUIRE_NOTHROW(tester.testBeginAndEndJobOnly());
+ }
// SECTION("Run with no LuminosityBlocks") {
// edm::test::TestProcessor tester(config);
diff --git a/Alignment/OfflineValidation/test/test_all_Phase2_cfg.py b/Alignment/OfflineValidation/test/test_all_Phase2_cfg.py
index 9cef9b6919392..ce80d16c0356c 100644
--- a/Alignment/OfflineValidation/test/test_all_Phase2_cfg.py
+++ b/Alignment/OfflineValidation/test/test_all_Phase2_cfg.py
@@ -12,7 +12,7 @@ class RefitType(Enum):
allFromGT = True
applyBows = True
applyExtraConditions = True
-theRefitter = RefitType.STANDARD
+theRefitter = RefitType.COMMON
_theTrackCollection = "generalTracks" #"ALCARECOTkAlMinBias" unfortunately not yet
from Configuration.Eras.Era_Phase2C17I13M9_cff import Phase2C17I13M9
@@ -59,7 +59,7 @@ class RefitType(Enum):
threshold = cms.untracked.string("INFO"),
default = cms.untracked.PSet(limit = cms.untracked.int32(0)),
FwkReport = cms.untracked.PSet(limit = cms.untracked.int32(-1),
- reportEvery = cms.untracked.int32(1000)
+ reportEvery = cms.untracked.int32(1)
),
PrimaryVertexValidation = cms.untracked.PSet( limit = cms.untracked.int32(-1)),
SplitVertexResolution = cms.untracked.PSet( limit = cms.untracked.int32(-1)),
@@ -193,7 +193,7 @@ class RefitType(Enum):
# Load and Configure Common Track Selection and refitting sequence
####################################################################
import Alignment.CommonAlignment.tools.trackselectionRefitting as trackselRefit
- process.seqTrackselRefit = trackselRefit.getSequence(process, 'ALCARECOTkAlMinBias',
+ process.seqTrackselRefit = trackselRefit.getSequence(process, _theTrackCollection ,
isPVValidation=True,
TTRHBuilder='WithAngleAndTemplate',
usePixelQualityFlag=True,
@@ -295,6 +295,11 @@ def switchClusterizerParameters(da):
TkClusParameters = switchClusterizerParameters(isDA)
)
+####################################################################
+# Needed to avoid dependency from Phase-0 strip conditions
+####################################################################
+#process.TrackerTrackHitFilter.isPhase2 = cms.bool(True)
+
####################################################################
# Path
####################################################################
@@ -348,10 +353,10 @@ def switchClusterizerParameters(da):
runControl = cms.untracked.bool(True),
runControlNumber = cms.untracked.vuint32(int(runboundary))
)
+#process.Tracer = cms.Service("Tracer")
process.p2 = cms.Path(process.HLTFilter +
process.seqTrackselRefit +
process.offlinePrimaryVerticesFromRefittedTrks +
process.PrimaryVertexResolution +
- process.myanalysis
- )
+ process.myanalysis)
diff --git a/Alignment/OfflineValidation/test/testingScripts/testPVValidation.sh b/Alignment/OfflineValidation/test/testingScripts/testPVValidation.sh
index c9b70a9464530..e58f4bcfac41c 100755
--- a/Alignment/OfflineValidation/test/testingScripts/testPVValidation.sh
+++ b/Alignment/OfflineValidation/test/testingScripts/testPVValidation.sh
@@ -3,4 +3,4 @@
function die { echo $1: status $2 ; exit $2; }
echo "TESTING Alignment/OfflineValidation ..."
-cmsRun ${LOCAL_TEST_DIR}/test_all_cfg.py || die "Failure running test_all_cfg.py" $?
+cmsRun ${CMSSW_BASE}/src/Alignment/OfflineValidation/test/test_all_cfg.py || die "Failure running test_all_cfg.py" $?
diff --git a/Alignment/OfflineValidation/test/testingScripts/test_unitDMR.sh b/Alignment/OfflineValidation/test/testingScripts/test_unitDMR.sh
index 5bc18e5023736..da3950b29d369 100755
--- a/Alignment/OfflineValidation/test/testingScripts/test_unitDMR.sh
+++ b/Alignment/OfflineValidation/test/testingScripts/test_unitDMR.sh
@@ -3,22 +3,28 @@
function die { echo $1: status $2 ; exit $2; }
echo "TESTING Alignment/DMR single configuration with json..."
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test/test_yaml/DMR/single/TestSingleMC/unitTest/1/
+pushd test_yaml/DMR/single/TestSingleMC/unitTest/1/
./cmsRun validation_cfg.py config=validation.json || die "Failure running DMR single configuration with json" $?
echo "TESTING Alignment/DMR single configuration standalone..."
./cmsRun validation_cfg.py || die "Failure running DMR single configuration standalone" $?
+popd
echo "TESTING DMR merge step"
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test/test_yaml/DMR/merge/TestMergeMC/1/
+pushd test_yaml/DMR/merge/TestMergeMC/1/
./DMRmerge validation.json || die "Failure running DMR merge step" $?
+popd
echo "TESTING DMR trends"
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test/test_yaml/DMR/trends/TestTrendMC/
+pushd test_yaml/DMR/trends/TestTrendMC/
./DMRtrends validation.json --verbose || die "Failure running DMR trends" $?
-
+popd
+
echo "TESTING DMR averaged"
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test/test_yaml/DMR/averaged/TestAveragedMC/MC/
+pushd test_yaml/DMR/averaged/TestAveragedMC/MC/
./mkLumiAveragedPlots.py validation.json || die "Failure running DMR averaged in merge mode" $?
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test/test_yaml/DMR/averaged/TestAveragedMC/plots/
+popd
+
+pushd test_yaml/DMR/averaged/TestAveragedMC/plots/
./mkLumiAveragedPlots.py validation.json || die "Failure running DMR averaged in plotting mode" $?
+popd
diff --git a/Alignment/OfflineValidation/test/testingScripts/test_unitDiMuonVertex.sh b/Alignment/OfflineValidation/test/testingScripts/test_unitDiMuonVertex.sh
index bf840b28a5828..284674d9104cd 100755
--- a/Alignment/OfflineValidation/test/testingScripts/test_unitDiMuonVertex.sh
+++ b/Alignment/OfflineValidation/test/testingScripts/test_unitDiMuonVertex.sh
@@ -3,4 +3,4 @@
function die { echo $1: status $2 ; exit $2; }
echo "TESTING Double Muon Vertex validation ..."
-cmsRun ${LOCAL_TEST_DIR}/DiMuonVertexValidation_cfg.py maxEvents=10 || die "Failure running DiMuonVertexValidation_cfg.py" $?
+cmsRun ${CMSSW_BASE}/src/Alignment/OfflineValidation/test/DiMuonVertexValidation_cfg.py maxEvents=10 || die "Failure running DiMuonVertexValidation_cfg.py" $?
diff --git a/Alignment/OfflineValidation/test/testingScripts/test_unitEoP.sh b/Alignment/OfflineValidation/test/testingScripts/test_unitEoP.sh
index 06b1693098004..3c570e8edf05f 100755
--- a/Alignment/OfflineValidation/test/testingScripts/test_unitEoP.sh
+++ b/Alignment/OfflineValidation/test/testingScripts/test_unitEoP.sh
@@ -2,7 +2,7 @@
function die { echo $1: status $2 ; exit $2; }
echo -e "\n\nTESTING eopTreeWriter (Pion Analysis) ..."
-cmsRun ${LOCAL_TEST_DIR}/eopTreeWriter_cfg.py unitTest=True maxEvents=100 || die "Failure running eopTreeWriter" $?
+cmsRun ${CMSSW_BASE}/src/Alignment/OfflineValidation/test/eopTreeWriter_cfg.py unitTest=True maxEvents=100 || die "Failure running eopTreeWriter" $?
echo -e "\n\nTESTING eopElecTreeWriter (Electron Analysis) ..."
-cmsRun ${LOCAL_TEST_DIR}/eopElecTreeWriter_cfg.py maxEvents=100 || die "Failure running eopElecTreeWriter" $?
+cmsRun ${CMSSW_BASE}/src/Alignment/OfflineValidation/test/eopElecTreeWriter_cfg.py maxEvents=100 || die "Failure running eopElecTreeWriter" $?
diff --git a/Alignment/OfflineValidation/test/testingScripts/test_unitGCP.sh b/Alignment/OfflineValidation/test/testingScripts/test_unitGCP.sh
index e4623cf84ad2e..e8c5f411071d8 100755
--- a/Alignment/OfflineValidation/test/testingScripts/test_unitGCP.sh
+++ b/Alignment/OfflineValidation/test/testingScripts/test_unitGCP.sh
@@ -3,19 +3,25 @@
function die { echo $1: status $2 ; exit $2; }
echo "TESTING GCP Ntuple creation"
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test/test_yaml/GCP/GCPdetUnits/Ntuples/SURun3_1
+pushd test_yaml/GCP/GCPdetUnits/Ntuples/SURun3_1
./cmsRun validation_cfg.py config=validation.json || die "Failure running GCP Ntuple for SURun3 alignment" $?
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test/test_yaml/GCP/GCPdetUnits/Ntuples/ideal_1
+popd
+
+pushd test_yaml/GCP/GCPdetUnits/Ntuples/ideal_1
./cmsRun validation_cfg.py config=validation.json || die "Failure running GCP Ntuple for ideal alignment" $?
+popd
echo "TESTING GCP comparison tree creation"
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test/test_yaml/GCP/GCPdetUnits/SURun3vsIdeal/1_vs_1/GCPtree/
+pushd test_yaml/GCP/GCPdetUnits/SURun3vsIdeal/1_vs_1/GCPtree/
./cmsRun validation_cfg.py config=validation.json || die "Failure running GCP comparison tree creation step" $?
+popd
echo "TESTING GCP cpp plots"
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test/test_yaml/GCP/GCPdetUnits/SURun3vsIdeal/1_vs_1/GCPcpp/
+pushd test_yaml/GCP/GCPdetUnits/SURun3vsIdeal/1_vs_1/GCPcpp/
./GCP validation.json -v || die "Failure running GCP cpp plots" $?
+popd
echo "TESTING GCP python plots"
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test/test_yaml/GCP/GCPdetUnits/SURun3vsIdeal/1_vs_1/GCPpython/
+pushd test_yaml/GCP/GCPdetUnits/SURun3vsIdeal/1_vs_1/GCPpython/
./GCPpyPlots.py validation.json || die "Failure running GCP python plots" $?
+popd
diff --git a/Alignment/OfflineValidation/test/testingScripts/test_unitJetHT.sh b/Alignment/OfflineValidation/test/testingScripts/test_unitJetHT.sh
new file mode 100755
index 0000000000000..c6e74305d7aa0
--- /dev/null
+++ b/Alignment/OfflineValidation/test/testingScripts/test_unitJetHT.sh
@@ -0,0 +1,24 @@
+#! /bin/bash
+
+function die { echo $1: status $2 ; exit $2; }
+
+echo "TESTING Alignment/JetHT single configuration with json..."
+pushd test_yaml/JetHT/single/testJob/unitTestJetHT
+./cmsRun validation_cfg.py config=validation.json || die "Failure running JetHT single configuration with json" $?
+
+echo "TESTING Alignment/JetHT single configuration standalone..."
+./cmsRun validation_cfg.py || die "Failure running JetHT single configuration standalone" $?
+popd
+
+echo "TESTING JetHT merge step"
+pushd test_yaml/JetHT/merge/testJob/unitTestJetHT
+./run.sh || die "Failure running JetHT merge step" $?
+popd
+
+echo "TESTING JetHT plotting"
+pushd test_yaml/JetHT/plot/testJob/
+./run.sh || die "Failure running JetHT plotting" $?
+popd
+
+echo "TESTING JetHT multi-IOV plotting"
+jetHtPlotter $CMSSW_BASE/src/Alignment/OfflineValidation/test/examples/jetHt_multiYearTrendPlot.json || die "Failure running multi-IOV JetHT plotting" $?
diff --git a/Alignment/OfflineValidation/test/testingScripts/test_unitMiscellanea.sh b/Alignment/OfflineValidation/test/testingScripts/test_unitMiscellanea.sh
index 409efa4d5a34b..1a4735bac6287 100755
--- a/Alignment/OfflineValidation/test/testingScripts/test_unitMiscellanea.sh
+++ b/Alignment/OfflineValidation/test/testingScripts/test_unitMiscellanea.sh
@@ -2,13 +2,13 @@
function die { echo $1: status $2 ; exit $2; }
echo "TESTING inspect ALCARECO data ..."
-cmsRun ${LOCAL_TEST_DIR}/inspectData_cfg.py unitTest=True trackCollection=ALCARECOTkAlCosmicsCTF0T || die "Failure running inspectData_cfg.py" $?
+cmsRun ${CMSSW_BASE}/src/Alignment/OfflineValidation/test/inspectData_cfg.py unitTest=True trackCollection=ALCARECOTkAlCosmicsCTF0T || die "Failure running inspectData_cfg.py" $?
echo "TESTING G4e refitter ..."
-cmsRun ${LOCAL_TEST_DIR}/testG4Refitter_cfg.py maxEvents=10 || die "Failure running testG4Refitter_cfg.py" $?
+cmsRun ${CMSSW_BASE}/src/Alignment/OfflineValidation/test/testG4Refitter_cfg.py maxEvents=10 || die "Failure running testG4Refitter_cfg.py" $?
echo "TESTING Pixel BaryCenter Analyser ..."
-cmsRun ${LOCAL_TEST_DIR}/PixelBaryCentreAnalyzer_cfg.py unitTest=True || die "Failure running PixelBaryCentreAnalyzer_cfg.py" $?
+cmsRun ${CMSSW_BASE}/src/Alignment/OfflineValidation/test/PixelBaryCentreAnalyzer_cfg.py unitTest=True || die "Failure running PixelBaryCentreAnalyzer_cfg.py" $?
echo "TESTING CosmicTrackSplitting Analyser ..."
-cmsRun ${LOCAL_TEST_DIR}/testSplitterValidation_cfg.py unitTest=True || die "Failure running testSplitterValidation_cfg.py" $?
+cmsRun ${CMSSW_BASE}/src/Alignment/OfflineValidation/test/testSplitterValidation_cfg.py unitTest=True || die "Failure running testSplitterValidation_cfg.py" $?
diff --git a/Alignment/OfflineValidation/test/testingScripts/test_unitPV.sh b/Alignment/OfflineValidation/test/testingScripts/test_unitPV.sh
index e9fe0c3e0cb9b..68c2bf75ce456 100755
--- a/Alignment/OfflineValidation/test/testingScripts/test_unitPV.sh
+++ b/Alignment/OfflineValidation/test/testingScripts/test_unitPV.sh
@@ -3,16 +3,19 @@
function die { echo $1: status $2 ; exit $2; }
echo "TESTING Alignment/PV single configuration with json..."
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test/test_yaml/PV/single/TestDATA/unitTestPV/317087/
+pushd test_yaml/PV/single/TestDATA/unitTestPV/317087/
./cmsRun validation_cfg.py config=validation.json || die "Failure running PV single configuration with json" $?
echo "TESTING Alignment/PV single configuration standalone..."
./cmsRun validation_cfg.py || die "Failure running PV single configuration standalone" $?
+popd
echo "TESTING PV merge step"
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test/test_yaml/PV/merge/TestDATA/317087/
+pushd test_yaml/PV/merge/TestDATA/317087/
./PVmerge validation.json --verbose || die "Failure running PV merge step" $?
+popd
echo "TESTING PV trends"
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test/test_yaml/PV/trends/TestDATA/
+pushd test_yaml/PV/trends/TestDATA/
./PVtrends validation.json --verbose || die "Failure running PV trends" $?
+popd
diff --git a/Alignment/OfflineValidation/test/testingScripts/test_unitPrimaryVertex.sh b/Alignment/OfflineValidation/test/testingScripts/test_unitPrimaryVertex.sh
index e32bbf639098e..23db69ccf39e2 100755
--- a/Alignment/OfflineValidation/test/testingScripts/test_unitPrimaryVertex.sh
+++ b/Alignment/OfflineValidation/test/testingScripts/test_unitPrimaryVertex.sh
@@ -3,7 +3,7 @@
function die { echo $1: status $2 ; exit $2; }
echo "TESTING Primary Vertex Validation: phase-1 setup ..."
-cmsRun ${LOCAL_TEST_DIR}/testPrimaryVertexRelatedValidations_cfg.py isPhase2=False maxEvents=100 || die "Failure running testPrimaryVertexRelatedValidations_cfg.py isPhase2=False" $?
+cmsRun ${CMSSW_BASE}/src/Alignment/OfflineValidation/test/testPrimaryVertexRelatedValidations_cfg.py isPhase2=False maxEvents=100 || die "Failure running testPrimaryVertexRelatedValidations_cfg.py isPhase2=False" $?
echo "TESTING Primary Vertex Validation: phase-2 setup ..."
-cmsRun ${LOCAL_TEST_DIR}/testPrimaryVertexRelatedValidations_cfg.py isPhase2=True maxEvents=10 || die "Failure running testPrimaryVertexRelatedValidations_cfg.py isPhase2=True" $?
+cmsRun ${CMSSW_BASE}/src/Alignment/OfflineValidation/test/testPrimaryVertexRelatedValidations_cfg.py isPhase2=True maxEvents=10 || die "Failure running testPrimaryVertexRelatedValidations_cfg.py isPhase2=True" $?
diff --git a/Alignment/OfflineValidation/test/testingScripts/test_unitSplitV.sh b/Alignment/OfflineValidation/test/testingScripts/test_unitSplitV.sh
index 1f75c69a51f37..2c51f82fd34a0 100755
--- a/Alignment/OfflineValidation/test/testingScripts/test_unitSplitV.sh
+++ b/Alignment/OfflineValidation/test/testingScripts/test_unitSplitV.sh
@@ -3,12 +3,14 @@
function die { echo $1: status $2 ; exit $2; }
echo "TESTING Alignment/SplitV single configuration with json..."
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test/test_yaml/SplitV/single/testUnits/unitTest/1/
+pushd test_yaml/SplitV/single/testUnits/unitTest/1/
./cmsRun validation_cfg.py config=validation.json || die "Failure running SplitV single configuration with json" $?
echo "TESTING Alignment/SplitV single configuration standalone..."
./cmsRun validation_cfg.py || die "Failure running PV single configuration standalone" $?
+popd
echo "TESTING SplotV merge step"
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test/test_yaml/SplitV/merge/testUnits/1/
+pushd test_yaml/SplitV/merge/testUnits/1/
./SplitVmerge validation.json --verbose || die "Failure running PV merge step" $?
+popd
diff --git a/Alignment/OfflineValidation/test/testingScripts/test_unitSubmitPVrbr.sh b/Alignment/OfflineValidation/test/testingScripts/test_unitSubmitPVrbr.sh
index 106016702ca84..0c99ceb34d40e 100755
--- a/Alignment/OfflineValidation/test/testingScripts/test_unitSubmitPVrbr.sh
+++ b/Alignment/OfflineValidation/test/testingScripts/test_unitSubmitPVrbr.sh
@@ -8,5 +8,6 @@ conddb --yes --db pro copy TrackerAlignment_Upgrade2017_design_v4 --destdb myfil
conddb --yes --db pro copy TrackerAlignmentErrorsExtended_Upgrade2017_design_v0 --destdb myfile.db
echo " TESTING Primary Vertex Validation run-by-run submission ..."
-submitPVValidationJobs.py -j UNIT_TEST -D /HLTPhysics/Run2016C-TkAlMinBias-07Dec2018-v1/ALCARECO -i ${LOCAL_TEST_DIR}/testPVValidation_Relvals_DATA.ini -r --unitTest || die "Failure running PV Validation run-by-run submission" $?
+submitPVValidationJobs.py -j UNIT_TEST -D /HLTPhysics/Run2016C-TkAlMinBias-07Dec2018-v1/ALCARECO \
+ -i ${CMSSW_BASE}/src/Alignment/OfflineValidation/test/testPVValidation_Relvals_DATA.ini -r --unitTest || die "Failure running PV Validation run-by-run submission" $?
diff --git a/Alignment/OfflineValidation/test/testingScripts/test_unitSubmitPVsplit.sh b/Alignment/OfflineValidation/test/testingScripts/test_unitSubmitPVsplit.sh
index 767455b55fcd2..44c7acd70b0b5 100755
--- a/Alignment/OfflineValidation/test/testingScripts/test_unitSubmitPVsplit.sh
+++ b/Alignment/OfflineValidation/test/testingScripts/test_unitSubmitPVsplit.sh
@@ -3,4 +3,5 @@
function die { echo $1: status $2 ; exit $2; }
echo " TESTING Split Vertex Validation submission ..."
-submitPVResolutionJobs.py -j UNIT_TEST -D /JetHT/Run2018C-TkAlMinBias-12Nov2019_UL2018-v2/ALCARECO -i ${LOCAL_TEST_DIR}/PVResolutionExample.ini --unitTest || die "Failure running Split Vertex Validation submission" $?
+submitPVResolutionJobs.py -j UNIT_TEST -D /JetHT/Run2018C-TkAlMinBias-12Nov2019_UL2018-v2/ALCARECO \
+ -i ${CMSSW_BASE}/src/Alignment/OfflineValidation/test/PVResolutionExample.ini --unitTest || die "Failure running Split Vertex Validation submission" $?
diff --git a/Alignment/OfflineValidation/test/testingScripts/validateAlignments.sh b/Alignment/OfflineValidation/test/testingScripts/validateAlignments.sh
index 8a2dcf55ad1db..e21c3ee8d68ed 100755
--- a/Alignment/OfflineValidation/test/testingScripts/validateAlignments.sh
+++ b/Alignment/OfflineValidation/test/testingScripts/validateAlignments.sh
@@ -1,12 +1,10 @@
#!/bin/zsh
-cd $CMSSW_BASE/src/Alignment/OfflineValidation/test
-
echo "Printing help"
validateAlignments.py -h
echo "Running over YAML"
-validateAlignments.py -v -f -d unit_test.yaml
+validateAlignments.py -v -f -d ${CMSSW_BASE}/src/Alignment/OfflineValidation/test/unit_test.yaml
echo "Running over JSON"
-validateAlignments.py -v -d -f unit_test.json
+validateAlignments.py -v -d -f ${CMSSW_BASE}/src/Alignment/OfflineValidation/test/unit_test.json
diff --git a/Alignment/OfflineValidation/test/unit_test.json b/Alignment/OfflineValidation/test/unit_test.json
index 9371c468ecdc2..d8f4bf780cbb1 100644
--- a/Alignment/OfflineValidation/test/unit_test.json
+++ b/Alignment/OfflineValidation/test/unit_test.json
@@ -1,5 +1,5 @@
{
- "LFS": "$CMSSW_BASE/src/UnitTest",
+ "LFS": "$CMSSW_BASE/tmp/UnitTest",
"name": "test_json",
"alignments": {
diff --git a/Alignment/OfflineValidation/test/unit_test.yaml b/Alignment/OfflineValidation/test/unit_test.yaml
index d31f4a53f8228..2e4f076d9e13d 100644
--- a/Alignment/OfflineValidation/test/unit_test.yaml
+++ b/Alignment/OfflineValidation/test/unit_test.yaml
@@ -1,4 +1,4 @@
-LFS: $CMSSW_BASE/src/UnitTest
+LFS: $CMSSW_BASE/tmp/UnitTest
name: test_yaml
alignments:
unitTest:
diff --git a/Alignment/TrackerAlignment/test/BuildFile.xml b/Alignment/TrackerAlignment/test/BuildFile.xml
index 0b3c95323ec1b..d2ce844fc57ba 100644
--- a/Alignment/TrackerAlignment/test/BuildFile.xml
+++ b/Alignment/TrackerAlignment/test/BuildFile.xml
@@ -24,5 +24,5 @@
-
+
diff --git a/Alignment/TrackerAlignment/test/pixelPositions.sh b/Alignment/TrackerAlignment/test/pixelPositions.sh
index db700fc4a4707..a31656b42d4a0 100755
--- a/Alignment/TrackerAlignment/test/pixelPositions.sh
+++ b/Alignment/TrackerAlignment/test/pixelPositions.sh
@@ -154,6 +154,7 @@ EOF
then
mkdir ${PLOTDIR}
cp -r $PLOTMILLEPEDEDIR/* ${PLOTDIR}
+ chmod -R +w ${PLOTDIR}
fi
cd ${PLOTDIR}
root -b -q -l allMillePede.C "pixelPositionChange.C+(\"${HEREIAM}/$TREEFILE1\", \"${HEREIAM}/$TREEFILE2\")"
diff --git a/BigProducts/Simulation/BuildFile.xml b/BigProducts/Simulation/BuildFile.xml
index 351008a7368d8..a8eae0f766fe2 100644
--- a/BigProducts/Simulation/BuildFile.xml
+++ b/BigProducts/Simulation/BuildFile.xml
@@ -34,8 +34,3 @@
-
-
-
-
-
diff --git a/CUDADataFormats/PortableTestObjects/src/classes_def.xml b/CUDADataFormats/PortableTestObjects/src/classes_def.xml
index 892bedcca23d6..a0d9d557d2f39 100644
--- a/CUDADataFormats/PortableTestObjects/src/classes_def.xml
+++ b/CUDADataFormats/PortableTestObjects/src/classes_def.xml
@@ -5,7 +5,7 @@
targetClass="cudatest::TestHostCollection"
version="[1-]"
source="portabletest::TestSoA layout_;"
- target="buffer_"
+ target="buffer_,layout_,view_"
embed="false">
-
diff --git a/CUDADataFormats/TrackingRecHit/interface/TrackingRecHitSoADevice.h b/CUDADataFormats/TrackingRecHit/interface/TrackingRecHitSoADevice.h
index c796725b2e8d0..ab0043930558d 100644
--- a/CUDADataFormats/TrackingRecHit/interface/TrackingRecHitSoADevice.h
+++ b/CUDADataFormats/TrackingRecHit/interface/TrackingRecHitSoADevice.h
@@ -48,7 +48,10 @@ class TrackingRecHitSoADevice : public cms::cuda::PortableDeviceCollection
diff --git a/Alignment/OfflineValidation/plugins/PixelBaryCentreAnalyzer.cc b/Alignment/OfflineValidation/plugins/PixelBaryCentreAnalyzer.cc
index e8c4baeba3afd..ab4c6f2bb565c 100644
--- a/Alignment/OfflineValidation/plugins/PixelBaryCentreAnalyzer.cc
+++ b/Alignment/OfflineValidation/plugins/PixelBaryCentreAnalyzer.cc
@@ -400,19 +400,19 @@ void PixelBaryCentreAnalyzer::analyze(const edm::Event& iEvent, const edm::Event
if (phase_ == 1) {
if (layer != 4) { // layer 1-3
- if (ladder % 2 != 0) { // odd ladder = inner = flipped
- nmodulesLayer_Flipped += nmodules_bpix[layer][ladder];
- BPIXLayer_Flipped += barycentreLayer[ladder];
- } else {
+ if (ladder % 2 != 0) { // odd ladder = outer ladder = unflipped
nmodulesLayer_NonFlipped += nmodules_bpix[layer][ladder];
BPIXLayer_NonFlipped += barycentreLayer[ladder];
+ } else { // even ladder = inner ladder = flipped
+ nmodulesLayer_Flipped += nmodules_bpix[layer][ladder];
+ BPIXLayer_Flipped += barycentreLayer[ladder];
}
} else { // layer-4
- if (ladder % 2 == 0) { // even ladder = inner = flipped
+ if (ladder % 2 != 0) { // odd ladder = inner = flipped
nmodulesLayer_Flipped += nmodules_bpix[layer][ladder];
BPIXLayer_Flipped += barycentreLayer[ladder];
- } else { // odd ladder = outer = non-flipped
+ } else { //even ladder = outer ladder = unflipped
nmodulesLayer_NonFlipped += nmodules_bpix[layer][ladder];
BPIXLayer_NonFlipped += barycentreLayer[ladder];
}